import string
import _log2vis

RTL, LTR = 1, 0
inencodings = ("iso-8859-8", "iso-8859-6", "UTF-8", "cp1255", "cp1256", "windows-1255", "windows-1256")
outencodings = ("iso-8859-8", "iso-8859-6", "cp1255", "cp1256", "windows-1255", "windows-1256")

def log2vis(text, width=80, direction=RTL, before=' ', after='\n', 
            inencoding='iso-8859-8', outencoding='iso-8859-8'):
    """ log2vis(text, width=80, direction=1, before=' ', after='\n', inencoding='iso-8859-8', outencoding='iso-8859-8'):
        
        Convert logical to visual, handling line breaks as well. 
        direction is either 0 (LTR) or 1 (RTL).
    """
    
    if outencoding not in outencodings:
        raise ValueError, "output encoding is invalid."
    
    if inencoding not in inencodings:
        raise ValueError, "output encoding is invalid."
            
    outtext = ""
    lines = []
    
    for log_line in string.split(text, '\n'):
        if len(log_line) and log_line[-1] == '\r': log_line = log_line[:-1]
        if len(log_line) > 8192: raise OverflowError, "Lines must be less than 8192 characters long."
        lines.append(_log2vis.log2vis(log_line, direction, inencoding, outencoding))
    
    if direction == RTL:
        # Align to right
        for line in lines:   
            while len(line) > width: # we need to divide
                # find first space after length
                fragment = string.split(line[-width:], ' ', 1)
                try:
                    fragment = fragment[1]
                except:
                    fragment = ""
                outtext = "%s%s%s%s" % (outtext, (before * (width - len(fragment) - 1) ), fragment, after)
                line = line[:-len(fragment)]

            outtext = "%s%s%s%s" % (outtext, (before * (width - len(line) - 1)), line, after)
    else:
        # Align to left
        for line in lines:
            if not line:
                outtext = outtext + after
                continue
            words = string.split(line)
            current = words.pop(0)
            for word in words:
                increment = 1 + len(word)
                if len(current) + increment > width:
                    outtext = "%s%s%s" % (outtext, current, after)
                    current = word
                else:
                    current = "%s %s" % (current, word)
            outtext = "%s%s%s" % (outtext, current, after)
            
    return outtext
